@@ -5,10 +5,12 @@ pkgsetcomp module
 
 """
 
+
 def __read_version_txt():
+    """read VERSION.txt into __version__ and version"""
     import os.path
     SETUPPY_PATH = os.path.abspath(
-        os.path.join(os.path.basename(__file__), '..'))
+        os.path.join(os.path.dirname(__file__), '..'))
     with open(os.path.join(SETUPPY_PATH, 'VERSION.txt')) as f:
         version = f.read().strip()
     return version
@@ -18,4 +20,4 @@ global __version__
 global version
 version = __version__ = __read_version_txt()
 
-#__ALL__ = ['pkgsetcomp', 'version', '__version__']
+# __ALL__ = ['pkgsetcomp', 'version', '__version__']
